import React, { lazy, Suspense } from "react";
import { Switch, Route } from "wouter";
import { queryClient } from "./lib/queryClient";
import { QueryClientProvider } from "@tanstack/react-query";
import { Toaster } from "@/components/ui/toaster";
import { TooltipProvider } from "@/components/ui/tooltip";
import { FilterProvider } from "./contexts/FilterContext";
import { BookmarkProvider } from "./contexts/BookmarkContextNew";
import Header from "@/components/Header";
import Footer from "@/components/Footer";

// Import main Home page directly to improve initial load experience
import Home from "@/pages/Home";

// Lazy load other pages to reduce initial bundle size
const NotFound = lazy(() => import("@/pages/not-found"));
const CourseDetail = lazy(() => import("@/pages/CourseDetail"));
const CourseDetailByUuid = lazy(() => import("@/pages/CourseDetailByUuid"));
const BookmarksPage = lazy(() => import("@/pages/BookmarksPage"));
const About = lazy(() => import("@/pages/About"));
const Contact = lazy(() => import("@/pages/Contact"));
const PersonalizedFinder = lazy(() => import("@/pages/PersonalizedFinder"));
const AdminDashboard = lazy(() => import("@/pages/Admin"));
const StateFilterTest = lazy(() => import("@/pages/StateFilterTest"));
const QuickStartGuide = lazy(() => import("@/pages/QuickStartGuide"));
const StateResources = lazy(() => import("@/pages/StateResources"));
const LearningPaths = lazy(() => import("@/pages/LearningPaths"));

// Loading spinner component for Suspense fallback
const LoadingSpinner = () => (
  <div className="flex items-center justify-center min-h-screen">
    <div className="animate-spin rounded-full h-12 w-12 border-b-2 border-primary"></div>
  </div>
);

function Router() {
  return (
    <Suspense fallback={<LoadingSpinner />}>
      <Switch>
        <Route path="/" component={Home} />
        <Route path="/course/:id" component={CourseDetail} />
        <Route path="/c/:uuid" component={CourseDetailByUuid} />
        <Route path="/bookmarks" component={BookmarksPage} />
        <Route path="/about" component={About} />
        <Route path="/skills-finder" component={PersonalizedFinder} />
        <Route path="/admin" component={AdminDashboard} />
        <Route path="/state-filter-test" component={StateFilterTest} />
        <Route path="/guide" component={QuickStartGuide} />
        <Route path="/learning-paths" component={LearningPaths} />
        <Route path="/career-resources" component={StateResources} />
        <Route path="/contact" component={Contact} />
        <Route component={NotFound} />
      </Switch>
    </Suspense>
  );
}

function App() {
  return (
    <QueryClientProvider client={queryClient}>
      <FilterProvider>
        <BookmarkProvider>
          <TooltipProvider>
            <div className="flex flex-col min-h-screen">
              <Header />
              <main className="flex-grow">
                <Router />
              </main>
              <Footer />
            </div>
            <Toaster />
            <div 
              className="fixed right-0 top-1/2 transform -translate-y-1/2 z-50 hidden md:block"
              style={{ 
                writingMode: 'vertical-rl', 
                textOrientation: 'mixed',
                backgroundColor: '#4338ca',
                borderRadius: '6px 0 0 6px',
                padding: '12px 8px',
                boxShadow: '0 4px 12px rgba(0, 0, 0, 0.15)',
                cursor: 'pointer'
              }}
              onClick={() => {
                // Calculate position to center in both screen and window
                const width = 700;
                const height = 500;
                const left = Math.round((window.screen.width - width) / 2);
                const top = Math.round((window.screen.height - height) / 2);
                
                const features = `scrollbars=yes,toolbar=no,width=${width},height=${height},top=${top},left=${left},screenX=${left},screenY=${top},location=no,status=no,menubar=no`;
                
                window.open(
                  'https://form.jotform.com/251354058430047',
                  'blank',
                  features
                );
              }}
            >
              <span className="text-white font-medium">
                Beta Feedback
              </span>
            </div>
          </TooltipProvider>
        </BookmarkProvider>
      </FilterProvider>
    </QueryClientProvider>
  );
}

export default App;